pub struct PolicyClient {
registry: PolicyRegistry,
}Expand description
Client for policy domain operations.
Obtained via PoliciesClientExt::policies on a [Client].
Fields
registry: PolicyRegistryImplementations
Sourceimpl PolicyClient
impl PolicyClient
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new PolicyClient with a freshly built registry.
Sourceimpl PolicyClient
impl PolicyClient
Sourcepub fn filter_by_type(
&self,
policies: Vec<PolicyView>,
organizations: Vec<ProfileOrganization>,
policy_type: PolicyType,
) -> Vec<PolicyView>
pub fn filter_by_type( &self, policies: Vec<PolicyView>, organizations: Vec<ProfileOrganization>, policy_type: PolicyType, ) -> Vec<PolicyView>
Filter policies of the given type for the current user.
Untyped FFI path: native/WASM callers pass a runtime policy_type integer.
Delegates to the registry, falling back to default rules for unknown types.